@@ -1,6 +1,6 @@
 #!/bin/sh
 
-for F in *.cgi
+for F in *.cgi *.psgi
 do
   echo $F
   podselect $F > $F.pod
